@@ -4,6 +4,7 @@
 import sys
 import gi
 import os.path
+import logging
 
 gi.require_version("Gtk", "4.0")
 gi.require_version("Adw", "1")
@@ -11,10 +12,14 @@ gi.require_version("GdkPixbuf", "2.0")
 
 from gi.repository import Adw, Gtk, Gio
 
+# asyncio setup
+import asyncio
+from ._async import policy
+
 from . import APP_ID, APP_GRESOURCE_PATH
-from .utils.validation import is_valid_music_file
-from .window import EartagWindow
-from .filemanager import EartagFileManager
+from .utils.validation import is_valid_music_file, get_mimetype
+from .window import EartagFileDialogType, EartagWindow
+from .logger import logger
 
 
 class Application(Adw.Application):
@@ -28,20 +33,19 @@ class Application(Adw.Application):
         self.devel = devel
         self.paths = []
         self.connect("open", self.on_open)
+        if devel:
+            logger.setLevel(logging.DEBUG)
+        logger.info(f"Starting Ear Tag {version}{' (development mode)' if devel else ''}")
 
     def on_open(self, app, files, *args):
-        if self.props.active_window:
-            window = self.props.active_window
-            window.open_mode = EartagFileManager.LOAD_INSERT
-
+        window = self.props.active_window
+        if window:
             paths = []
             for file in files:
                 path = file.get_path()
                 if path:
                     paths.append(path)
-            window.load_files_from_paths(paths)
-
-            window.open_mode = EartagFileManager.LOAD_OVERWRITE
+            window.file_manager.load_files(paths)
         else:
             for file in files:
                 path = file.get_path()
@@ -72,37 +76,24 @@ class Application(Adw.Application):
 
             self.create_action("next_file", self.on_next_action, "<Alt>Right")
             self.create_action("previous_file", self.on_previous_action, "<Alt>Left")
-            self.create_action(
-                "close_selected", self.on_close_selected_action, "<Ctrl>w"
-            )
-            self.create_action(
+            self.create_action("close_selected", self.on_close_selected_action, "<Ctrl>w")
+            self.select_all_action = self.create_action(
                 "select_all", self.on_select_all_action, "<Ctrl><Shift>a"
             )
 
             self.create_action("toggle_sidebar", self.on_toggle_sidebar_action, "F9")
             self.create_action("open_menu", self.on_open_menu_action, "F10")
 
-            self.sort_action = self.create_action("sort", self.on_sort_action, None)
-            self.sort_action.set_enabled(False)
-
-            self.rename_action = self.create_action(
-                "rename", self.on_rename_action, None
-            )
+            self.rename_action = self.create_action("rename", self.on_rename_action, None)
             self.rename_action.set_enabled(False)
 
-            self.extract_action = self.create_action(
-                "extract", self.on_extract_action, None
-            )
+            self.extract_action = self.create_action("extract", self.on_extract_action, None)
             self.extract_action.set_enabled(False)
 
-            self.identify_action = self.create_action(
-                "identify", self.on_identify_action, None
-            )
+            self.identify_action = self.create_action("identify", self.on_identify_action, None)
             self.identify_action.set_enabled(False)
 
-            self.undo_all_action = self.create_action(
-                "undo_all", self.on_undo_all_action, None
-            )
+            self.undo_all_action = self.create_action("undo_all", self.on_undo_all_action, None)
             self.undo_all_action.set_enabled(False)
 
             self.delete_all_tags_action = self.create_action(
@@ -127,9 +118,6 @@ class Application(Adw.Application):
     def on_save_action(self, widget, _):
         self.get_active_window().file_manager.save()
 
-    def on_sort_action(self, widget, _):
-        self.get_active_window().run_sort()
-
     def on_rename_action(self, widget, _):
         self.get_active_window().show_rename_dialog()
 
@@ -156,7 +144,7 @@ class Application(Adw.Application):
         about = Adw.AboutDialog(
             application_name=self._("Ear Tag"),
             application_icon=APP_ID,
-            developers=["knuxify"],
+            developers=["knuxify https://tilde.town/~knuxify"],
             artists=["Jakub Steiner", "Igor Dyatlov"],
             license_type=Gtk.License.MIT_X11,
             issue_url="https://gitlab.gnome.org/World/eartag/-/issues",
@@ -177,33 +165,42 @@ class Application(Adw.Application):
             f"libadwaita: {Adw.get_major_version()}.{Adw.get_minor_version()}.{Adw.get_micro_version()}"  # noqa: E501
         )
 
-        import magic
+        import filetype
+
+        lib_versions.append(f"filetype.py: {filetype.version}")
 
-        try:
-            lib_versions.append(f"libmagic: {magic.version()}")
-        except NotImplementedError:
-            lib_versions.append("libmagic: version data N/A")
         import mutagen
 
         lib_versions.append(f"mutagen: {mutagen.version_string}")
+
         import PIL
 
         lib_versions.append(f"pillow: {PIL.__version__}")
 
+        import aiohttp
+
+        lib_versions.append(f"aiohttp: {aiohttp.__version__}")
+
+        import xxhash
+
+        lib_versions.append(
+            f"xxhash: {xxhash.VERSION} (using library version {xxhash.XXHASH_VERSION})"
+        )
+
         lib_version_str = "\n - ".join(lib_versions)
 
         opened_file_list = []
         for file in self.props.active_window.file_manager.files:
             opened_file_list.append(
-                f"{file.path}, {magic.from_file(file.path, mime=True)}, {file.__gtype_name__}"
+                f"{file.path}, {get_mimetype(file.path)}, {file.__gtype_name__}"
             )  # noqa: E501
 
         opened_file_list_str = "\n - ".join(opened_file_list) or "None"
 
         about.set_debug_info(
-            f"""Ear Tag {self.version}{' (Development version)' if self.devel else ''}
+            f"""Ear Tag {self.version}{" (Development version)" if self.devel else ""}
 
-Running in Flatpak: {os.path.exists('/.flatpak-info') and 'YES' or 'NO'}
+Running in Flatpak: {os.path.exists("/.flatpak-info") and "YES" or "NO"}
 
 Dependency versions:
  - {lib_version_str}
@@ -216,13 +213,15 @@ Opened files:
 
     def on_open_file_action(self, widget, _):
         window = self.get_active_window()
-        window.open_mode = EartagFileManager.LOAD_OVERWRITE
-        window.show_file_chooser()
+        window.show_file_chooser(
+            EartagFileDialogType.TYPE_FILE | EartagFileDialogType.MODE_OVERWRITE
+        )
 
     def on_open_folder_action(self, widget, _):
         window = self.get_active_window()
-        window.open_mode = EartagFileManager.LOAD_OVERWRITE
-        window.show_file_chooser(folders=True)
+        window.show_file_chooser(
+            EartagFileDialogType.TYPE_FOLDER | EartagFileDialogType.MODE_OVERWRITE
+        )
 
     def on_next_action(self, *args):
         win = self.props.active_window
@@ -278,5 +277,6 @@ Opened files:
 
 
 def main(version, devel):
+    asyncio.set_event_loop_policy(policy)
     app = Application(version, devel)
     return app.run(sys.argv)
